<?php

/**
 * @file
 * Page callback for gmail contact invite page.
 */

/**
 * Initiate invite page for gmail.
 *
 * @return string
 */
function gmail_contact_invite_page() {
  if (isset($_GET["code"])) {
    // Store auth code in session.
    $_SESSION['gmail_auth_code'] = $_GET['code'];

    // Redirect to gmail invite form.
    drupal_goto('gmail-invite');
  }
  else {
    return t('You are not supposed to be on this page.');
  }

}

/**
 * Page callback for gmail invite page.
 *
 * @param $form_state
 * @return mixed
 */
function gmail_contact_invite_form($form_state) {
  // Flush contact option from session if there're session available for
  // initial form rendering. We should not have contacts info stored at
  // session for long time.
  if (empty($form_state['post']) && isset($_SESSION['gmail_contact_options'])) {
    unset($_SESSION['gmail_contact_options']);
  }

  // Use the contact options from session if this form is not rendered
  // initially. E.g, this form is rendered after validation fails.
  if (!empty($form_state['post']) && isset($_SESSION['gmail_contact_options'])) {
    $options = $_SESSION['gmail_contact_options'];
  }
  else {
    if (!isset($_SESSION['gmail_auth_code'])) {
      $form['text'] = array(
        '#value' => t('You are not supposed to be on this page.'),
      );
      return $form;
    }

    $auth_code = $_SESSION['gmail_auth_code'];
    $xmlresponse = gmail_contact_get_gmail_contacts($auth_code);
    $contacts = gmail_contact_parse_gmail_contacts($xmlresponse);

    //$contacts = array(
    //  array('email' => '22@e.c', 'name' => 'Rulin er'),
    //  array('email' => '22@e.cs', 'name' => 'Bulin er'),
    //  array('email' => '22@e.ce', 'name' => 'Aulin aa'),
    //  array('email' => '22@e.cess', 'name' => 'amlin ac'),
    //);

    // Display message to user if no contacts found.
    if (empty($contacts)) {
      $form['message'] = array(
        '#value' => t("It seems your account doesn't have contacts at this moment.<br>
        Or all your contacts don't have name associated.
        Please note if one contact doesn't have name, it will not display here."),
      );

      return $form;
    }

    $options = array();
    $uc = variable_get('gmail_contact_capitalize_name', '');
    foreach ($contacts as $contact) {
      if ($uc) {
        // Check this name before render it out.
        $contact['name'] = check_plain($contact['name']);
        $options[$contact['email']] = ucfirst($contact['name']);
      }
      else {
        $options[$contact['email']] = $contact['name'];
      }
    }

    $sort = variable_get('gmail_contact_sort', '');
    if ($sort) {
      asort($options);
    }

    // Store options in session, so we can use it later, especially when
    // validation fails.
    $_SESSION['gmail_contact_options'] = $options;
  }

  $form['select_all'] = array(
    '#title' => t('Select all'),
    '#type' => 'checkbox',
    '#bix_flag' => TRUE,
  );
  $form['contacts'] = array(
    '#type' => 'checkboxes',
    '#options' => $options,
  );
  $form['contacts_options'] = array(
    '#type' => 'value',
    '#value' => $options,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit'),
  );

  return $form;
}

/**
 * Validate callback for invite form.
 *
 * @param $form
 * @param $form_state
 */
function gmail_contact_invite_form_validate($form, &$form_state) {

  $emails = array();
  $all_contacts = $form_state['values']['contacts'];
  foreach ($all_contacts as $contact) {
    if ($contact) {
      $emails[] = $contact;
    }
  }

  if (empty($emails)) {
    $msg = t('You should select at least one contact to proceed.');
    form_set_error('contacts', $msg);
    return;
  }

  // Save valid emails.
  $form_state['emails'] = $emails;

}

/**
 * Submit callback for invite form. I.e, Send emails out.
 *
 * @param $form
 * @param $form_state
 */
function gmail_contact_invite_form_submit($form, &$form_state) {
  global $user, $language;

  $site_mail = variable_get('site_mail', $user->mail);
  $from = variable_get('gmail_contact_email_address', $site_mail);

  if (module_exists('token')) {
    $from = token_replace($from);
  }

  //$emails = $form_state['values']['emails'];
  $emails = $form_state['emails'];

  // Add those email work to drupal queue.
  //$queue = drupal_queue_get('gmail_invite');
  //$queue->createQueue();

  foreach ($emails as $email) {

    // Set variables, and add email work to drupal queue.
    //$vars = array();
    //$queue->createItem($vars);
    $result = drupal_mail('gmail_contact', 'invite', $email, $language, array(), $from, TRUE);
  }

  $message = t('Your invitation will be sent shortly.');
  drupal_set_message($message);

  $form_state['redirect'] = "<front>";

  // Remove contact options from session, once one request is done. We should
  // not leave these data in session for long time.
  unset($_SESSION['gmail_contact_options']);
}

